package com.example.sdk;

import com.alibaba.cloudapi.sdk.model.HttpClientBuilderParams;
import com.alibaba.fastjson.JSON;

import com.example.sdk.common.GatewayResponse;
import com.example.sdk.progress.GetTaskProgressRequest;
import com.example.sdk.progress.GetTaskProgressResponse;
import com.example.sdk.result.GetTaskResultRequest;
import com.example.sdk.result.GetTaskResultResponse;
import com.example.sdk.submit.ExampleInputs;
import com.example.sdk.submit.SubmitTaskRequest;
import com.example.sdk.submit.SubmitTaskResponse;

/**
 * Hello world!
 */
public class Demo {

    static {
        // 1. 初始化客户端（只需执行一次）
        HttpClientBuilderParams params = new HttpClientBuilderParams();
        // 设置网关域名、AppKey、AppSecret等信息
        // TODO 请替换为实际的 AppKey 和 AppSecret
        params.setAppKey("AccessKeyId");
        params.setAppSecret("AccessKeySecret");
        params.setHost("openai.edu-aliyun.com");
        // 也可以配合 setConnectionTimeoutMillis、setMaxConnections 等进行更多配置
        GatewayApiClient.getInstance().init(params);
    }

    private static SubmitTaskResponse submitTask(SubmitTaskRequest request) {
        GatewayResponse<SubmitTaskResponse> response =
            GatewayApiClient.getInstance().invoke("/scc/comfy_prompt", request, SubmitTaskResponse.class);

        // 根据网关返回处理结果
        if (response.getStatus() == 10) {
            // 成功
            return response.getData();
        } else {
            // 失败
            System.err.println("网关调用失败, 错误码: " + response.getErrCode()
                + ", 错误信息: " + response.getErrMessage());
            System.err.println("服务子错误码: " + response.getSubErrCode()
                + ", 服务子错误信息: " + response.getSubErrMessage());
            throw new RuntimeException("任务提交失败：" + response.getErrMessage());
        }
    }

    private static GetTaskProgressResponse getTaskProgress(String taskId) {
        GatewayResponse<GetTaskProgressResponse> response =
            GatewayApiClient.getInstance().invoke("/scc/comfy_get_progress", new GetTaskProgressRequest(taskId),
                GetTaskProgressResponse.class);

        // 根据网关返回处理结果
        if (response.getStatus() == 10) {
            // 成功
            return response.getData();
        } else {
            // 失败
            System.err.println("网关调用失败, 错误码: " + response.getErrCode()
                + ", 错误信息: " + response.getErrMessage());
            System.err.println("服务子错误码: " + response.getSubErrCode()
                + ", 服务子错误信息: " + response.getSubErrMessage());
            throw new RuntimeException("获取任务进度失败：" + response.getErrMessage());
        }
    }

    private static GetTaskResultResponse getTaskResult(String taskId) {
        GatewayResponse<GetTaskResultResponse> response =
            GatewayApiClient.getInstance().invoke("/scc/comfy_get_result", new GetTaskResultRequest(taskId),
                GetTaskResultResponse.class);

        // 根据网关返回处理结果
        if (response.getStatus() == 10) {
            // 成功
            return response.getData();
        } else {
            // 失败
            System.err.println("网关调用失败, 错误码: " + response.getErrCode()
                + ", 错误信息: " + response.getErrMessage());
            System.err.println("服务子错误码: " + response.getSubErrCode()
                + ", 服务子错误信息: " + response.getSubErrMessage());
            throw new RuntimeException("获取任务结果失败：" + response.getErrMessage());
        }
    }

    public static void main(String[] args) {

        SubmitTaskResponse task = submitTask(SubmitTaskRequest.builder()
            // TODO workflowId 请替换为实际的 workflowId
            .workflowId("xxx")
            .randomiseSeeds(true)
            .aliasId("main")
            .inputs(ExampleInputs.builder()
                .gender("女生")
                // TODO 图片地址请替换为实际图片地址
                .photo("https://example.com/example.png")
                .build())
            .build());
        System.out.println("任务提交成功，任务ID：" + task.getTaskId());

        // 轮训查询进度，间隔 3s，最大等待 5min
        for (int i = 0; i < 100; i++) {
            GetTaskProgressResponse progress = getTaskProgress(task.getTaskId());
            System.out.println("任务进度：" + progress.getProgress());
            if ("succeeded".equals(progress.getStatus())) {
                break;
            }
            try {
                Thread.sleep(3000);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }

        GetTaskResultResponse result = getTaskResult(task.getTaskId());
        System.out.println("任务结果：" + JSON.toJSONString(result.getResult()));
    }
}
